
#ifndef KGEOMAP_EXPORT_H
#define KGEOMAP_EXPORT_H

#ifdef LIBKGEOMAP_STATIC_DEFINE
#  define KGEOMAP_EXPORT
#  define LIBKGEOMAP_NO_EXPORT
#else
#  ifndef KGEOMAP_EXPORT
#    ifdef KF5KGeoMap_EXPORTS
        /* We are building this library */
#      define KGEOMAP_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KGEOMAP_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LIBKGEOMAP_NO_EXPORT
#    define LIBKGEOMAP_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LIBKGEOMAP_DEPRECATED
#  define LIBKGEOMAP_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBKGEOMAP_DEPRECATED_EXPORT
#  define LIBKGEOMAP_DEPRECATED_EXPORT KGEOMAP_EXPORT LIBKGEOMAP_DEPRECATED
#endif

#ifndef LIBKGEOMAP_DEPRECATED_NO_EXPORT
#  define LIBKGEOMAP_DEPRECATED_NO_EXPORT LIBKGEOMAP_NO_EXPORT LIBKGEOMAP_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBKGEOMAP_NO_DEPRECATED
#    define LIBKGEOMAP_NO_DEPRECATED
#  endif
#endif

#endif
